@@ -20,13 +20,17 @@ class Backend:
     _terminator: Thread
     _backend_thread_queue: List[Thread]
     _running_backend_threads: List[Thread]
+    _debug:bool
 
-    def __init__(self, max_num_threads: int = 4):
+    def __init__(self, max_num_threads: int = 4, debug: bool = False):
+        self._debug = debug
         if os.path.isfile("backend.jar"):
-            logger.info("Found simulation backend executable file.")
+            if self.debug:
+                logger.info("Found simulation backend executable file.")
             self._ready = True
         else:
-            logger.error("Can not find simulation backend executable file.")
+            if self.debug:
+                logger.error("Can not find simulation backend executable file.")
             self._ready = False
         self._terminated = False
         self._max_num_threads = max_num_threads
@@ -60,6 +64,10 @@ class Backend:
     @property
     def running_backend_threads(self):
         return self._running_backend_threads
+    
+    @property
+    def debug(self):
+        return self._debug
 
     @staticmethod
     def generate_config(
@@ -129,7 +137,7 @@ class Backend:
 
         if os.path.exists("configs") is False:
             os.makedirs("configs")
-
+        
         logger.info(f"Generated new simulation configuration file\t {config_file}.")
         with open("configs/" + config_file, "w+") as config_file:
             json.dump(sim_config, config_file, indent=4)
@@ -143,18 +151,11 @@ class Backend:
 
     def stop(self):
         if self.main_thread.is_alive():
+            
             def wait_for_running_process():
-                all_threads_complete = False
-                while all_threads_complete is not True:
-                    all_threads_complete = True
-                    for thread in self.running_backend_threads:
-                        if thread.is_alive():
-                            all_threads_complete = False
-                            break
-                        else:
-                            continue
-                if all_threads_complete:
-                    self._terminated = True
+                while len(self._running_backend_threads) > 0:
+                    pass
+                self._terminated = True
 
             self._terminator = Thread(target=wait_for_running_process, name="terminator")
             self._terminator.start()
@@ -209,8 +210,9 @@ class Backend:
                         logger.info(f"Experiment\t {backend_thread.name} \tfinsihed.")
 
             while (
-                len(self.running_backend_threads) < 6
+                len(self.running_backend_threads) < self.max_num_threads
                 and len(self.backend_thread_queue) != 0
+                and self.terminated != True
             ):
                 backend_thread = self.backend_thread_queue.pop(0)
                 self._running_backend_threads.append(backend_thread)
