@@ -16,10 +16,13 @@ class Microservice:
     _cpu_ratio: int
     _ram_ratio: int
     _bw_ratio: int
+    _idle_cpu: int
+    _idle_ram: int
+    _idle_bw: int
     _auto_scale: List[AutoScale]
 
     def __init__(self, name: str, size: int, cpus: int, replicas: int, max_replicas: int,
-                 cpu_ratio: int, ram_ratio: int, bw_ratio: int):
+                 cpu_ratio: int, ram_ratio: int, bw_ratio: int, idle_cpu: int = None, idle_ram: int = None, idle_bw: int = None):
         """
         Create a new Microservice with the given name, size, cpus, ram, bw, replicas, max_replicas, cpu_ratio, ram_ratio and bw_ratio.
 
@@ -37,14 +40,26 @@ class Microservice:
         self._id = uuid4()
         self._name = name
         self._size = size
-        self._cpus = cpus
         self._replicas = replicas
         self._max_replicas = max_replicas
         self._cpu_ratio = cpu_ratio
         self._ram_ratio = ram_ratio
         self._bw_ratio = bw_ratio
-        self._ram = round(ram_ratio * cpus / (cpu_ratio/100))
-        self._bw = round(bw_ratio * cpus / (cpu_ratio/100))
+        if idle_cpu is not None:
+            self._idle_cpu = idle_cpu
+        else:
+            self._idle_cpu = cpu_ratio
+        if idle_ram is not None:
+            self._idle_ram = idle_ram
+        else:
+            self._idle_ram = ram_ratio
+        if idle_bw is not None:
+            self._idle_bw = idle_bw
+        else:
+            self._idle_bw = bw_ratio  
+        self._cpus = cpus + self.idle_cpu/100
+        self._ram = round(ram_ratio * cpus / (cpu_ratio/100)) + self.idle_ram
+        self._bw = round(bw_ratio * cpus / (cpu_ratio/100)) + self.idle_bw
         self._auto_scale = list()
         
     def add_auto_scale(self, telemetry:str, threshold:float):
@@ -110,6 +125,18 @@ class Microservice:
     def bw_ratio(self):
         return self._bw_ratio
     
+    @property
+    def idle_cpu(self):
+        return self._idle_cpu
+    
+    @property
+    def idle_ram(self):
+        return self._idle_ram
+    
+    @property
+    def idle_bw(self):
+        return self._idle_bw
+    
     @property
     def auto_scale(self):
         return self._auto_scale
\ No newline at end of file
